==> libzypp_17.7.0.orig.tar.gz: libzypp-17.7.0/zypp/parser/susetags/RepoIndex.cc <==
/*---------------------------------------------------------------------\
|                          ____ _   __ __ ___                          |
|                         |__  / \ / / . \ . \                         |
|                           / / \ V /|  _/  _/                         |
|                          / /__ | | | | | |                           |
|                         /_____||_| |_| |_|                           |
|                                                                      |
\---------------------------------------------------------------------*/
/** \file	zypp/parser/susetags/RepoIndex.cc
 *
*/
#include <iostream>
#include "zypp/base/LogTools.h"

#include "zypp/parser/susetags/RepoIndex.h"

using std::endl;
#undef  ZYPP_BASE_LOGGER_LOGGROUP
#define ZYPP_BASE_LOGGER_LOGGROUP "parser::susetags"

///////////////////////////////////////////////////////////////////
namespace zypp
{ /////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////
  namespace parser
  { /////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////
    namespace susetags
    { /////////////////////////////////////////////////////////////////

      IMPL_PTR_TYPE(RepoIndex);

      std::ostream & RepoIndex::dumpOn( std::ostream & str ) const
      {
        return str
            << "RepoIndex checksums: META files " << metaFileChecksums.size()
            << ", HASH files " << mediaFileChecksums.size()
            << ", KEY files " << signingKeys.size();
      }

      /////////////////////////////////////////////////////////////////
    } // namespace susetags
    ///////////////////////////////////////////////////////////////////
    /////////////////////////////////////////////////////////////////
  } // namespace parser
  ///////////////////////////////////////////////////////////////////
  /////////////////////////////////////////////////////////////////
} // namespace zypp
///////////////////////////////////////////////////////////////////

==> libzypp_17.36.7.orig.tar.gz: libzypp-17.36.7/zypp/parser/susetags/RepoIndex.cc <==
/*---------------------------------------------------------------------\
|                          ____ _   __ __ ___                          |
|                         |__  / \ / / . \ . \                         |
|                           / / \ V /|  _/  _/                         |
|                          / /__ | | | | | |                           |
|                         /_____||_| |_| |_|                           |
|                                                                      |
\---------------------------------------------------------------------*/
/** \file	zypp/parser/susetags/RepoIndex.cc
 *
*/
#include <iostream>
#include <zypp/base/LogTools.h>

#include <zypp/parser/susetags/RepoIndex.h>

using std::endl;
#undef  ZYPP_BASE_LOGGER_LOGGROUP
#define ZYPP_BASE_LOGGER_LOGGROUP "parser::susetags"

///////////////////////////////////////////////////////////////////
namespace zypp
{ /////////////////////////////////////////////////////////////////
  ///////////////////////////////////////////////////////////////////
  namespace parser
  { /////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////
    namespace susetags
    { /////////////////////////////////////////////////////////////////

      IMPL_PTR_TYPE(RepoIndex);

      std::ostream & RepoIndex::dumpOn( std::ostream & str ) const
      {
        return str
            << "RepoIndex checksums: META files " << metaFileChecksums.size()
            << ", HASH files " << mediaFileChecksums.size()
            << ", KEY files " << signingKeys.size();
      }

      /////////////////////////////////////////////////////////////////
    } // namespace susetags
    ///////////////////////////////////////////////////////////////////
    /////////////////////////////////////////////////////////////////
  } // namespace parser
  ///////////////////////////////////////////////////////////////////
  /////////////////////////////////////////////////////////////////
} // namespace zypp
///////////////////////////////////////////////////////////////////
